# kubecfg

Python library and cli utility to check k8s client configurations


[![PyPi](https://img.shields.io/pypi/v/kubecfg.svg?style=flat-square)](https://pypi.python.org/pypi/kubecfg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](https://github.com/ambv/black)


![Features](https://github.com/joaompinto/kubecfg/raw/main/imgs/features.png)

# Install
```sh
pip install kubecfg
```

# Run
```sh
kubecfg
```
